@@ -1,4 +1,3 @@
-import warnings
 from datetime import timedelta
 from urllib.parse import urljoin, urlparse
 
@@ -19,6 +18,11 @@ from keg_auth.libs import get_domain_from_email
 from keg_auth.model import get_username_key, get_username
 from keg_auth.model.entity_registry import RegistryError
 
+try:
+    import flask_wtf
+except ImportError:
+    pass  # pragma: no cover
+
 try:
     import flask_jwt_extended
 except ImportError:
@@ -44,6 +48,10 @@ class UserInvalidAuth(Exception):
         self.user = user
 
 
+class AttemptBlocked(Exception):
+    pass
+
+
 class RequestLoader(object):
     """ Generic loader interface for determining if a user should be logged in"""
 
@@ -100,6 +108,7 @@ class ViewResponder(object):
         `template_name` is passed to `flask.render_template` by default
     """
     template_name = None
+    _csrf_custom_handling = False
 
     def __init__(self, parent):
         self.template_args = {}
@@ -111,7 +120,40 @@ class ViewResponder(object):
     def render(self):
         return flask.render_template(self.template_name, **self.template_args)
 
+    def handle_csrf(self):
+        """ For some views that are rate-limited, we want to log all attempts, including
+        those that would fail CSRF validation. Because of this, we need to circumvent
+        flask-csrf's default before-request hook. The auth manager will work to exempt
+        any of our auth endpoints whose class is marked with _csrf_custom_handling.
+
+        If CSRF fails, ensure the attempt is logged, and then raise the error.
+
+        If CSRF succeeds, the ensuing view responder methods should do any appropriate
+        logging.
+        """
+        app = flask.current_app
+
+        if (
+            'csrf' not in app.extensions
+            or not app.config['WTF_CSRF_ENABLED']
+            or not app.config['WTF_CSRF_CHECK_DEFAULT']
+            or flask.request.method not in app.config['WTF_CSRF_METHODS']
+        ):
+            return
+
+        try:
+            app.extensions['csrf'].protect()
+        except flask_wtf.csrf.CSRFError:
+            self.on_csrf_error()
+            raise
+
+    def on_csrf_error(self):
+        pass
+
     def __call__(self, *args, **kwargs):
+        if self._csrf_custom_handling:
+            self.handle_csrf()
+
         method_name = flask.request.method.lower()
         method_obj = getattr(self, method_name, None)
         if not method_obj:
@@ -253,6 +295,25 @@ class AttemptLimitMixin(object):
             raise Exception('Rate limiting is enabled, but the attempt entity is not registered')
         return True
 
+    def check_blocking(self, user_input, success=False):
+        """Generic blocking method that will create an attempt log, and notify the calling
+        method (via exception) if the attempt is blocked.
+
+        Returns the attempt log if not blocked. If ``success`` is left False (default), The
+        calling method will be responsible to set the attempt log's success flag as needed.
+        """
+        attempt_log = None
+        if self.should_limit_attempts():
+            if self.is_attempt_blocked(user_input):
+                # If we are rate-limiting this attempt, we don't want to proceed with validation.
+                # Validating may still allow brute forcing by measuring response time.
+                attempt_log = self.log_attempt(user_input, success=False, is_during_lockout=True)
+                self.on_attempt_blocked()
+                raise AttemptBlocked
+            else:
+                attempt_log = self.log_attempt(user_input, success=success)
+        return attempt_log
+
     @property
     def should_filter_ip(self):
         return flask.current_app.config.get('KEGAUTH_ATTEMPT_IP_LIMIT', False)
@@ -365,7 +426,7 @@ class AttemptLimitMixin(object):
 class PasswordSetterResponderBase(FormResponderMixin, ViewResponder):
     """ Base logic for resetting passwords and verifying accounts via token"""
     form_cls = forms.SetPassword
-    template_name = 'keg_auth/set-password.html'
+    template_name = 'keg-auth/set-password.html'
     flash_invalid_token = _(
         'Authentication token was invalid or expired.  Please fill out the'
         ' form below to get a new token.'
@@ -425,13 +486,12 @@ class ResetPasswordViewResponder(AttemptLimitMixin, PasswordSetterResponderBase)
     on_success_endpoint = 'after-reset'
 
     def on_form_valid(self, form):
-        if self.should_limit_attempts():
-            if self.is_attempt_blocked(get_username(self.user)):
-                self.log_attempt(get_username(self.user), success=False, is_during_lockout=True)
-                self.on_attempt_blocked()
-                return
-
-            self.log_attempt(get_username(self.user), success=True)
+        try:
+            self.check_blocking(get_username(self.user), success=True)
+        except AttemptBlocked:
+            # If we are rate-limiting this attempt, we don't want to proceed with validation.
+            # Validating may still allow brute forcing by measuring response time.
+            return
 
         new_password = form.password.data
         self.user.change_password(self.token, new_password)
@@ -477,28 +537,42 @@ class VerifyAccountViewResponder(PasswordSetterResponderBase):
 class PasswordFormViewResponder(AttemptLimitMixin, LoginResponderMixin,
                                 FormResponderMixin, ViewResponder):
     """ Master responder for username/password-style logins, using a login form"""
-    template_name = 'keg_auth/login.html'
+    template_name = 'keg-auth/login.html'
     page_title = _('Log In')
     flash_invalid_password = _('Invalid password.'), 'error'
+    _csrf_custom_handling = True
 
     @property
     def form_cls(self):
         return forms.login_form()
 
+    def on_form_error(self, form):
+        super().on_form_error(form)
+        username = form.login_id.data
+        try:
+            # ensure we log this even though the form didn't validate
+            self.check_blocking(username)
+        except AttemptBlocked:
+            pass
+
+    def on_csrf_error(self):
+        username = flask.request.form.get('login_id', '')
+        try:
+            # ensure we log this even though the form didn't validate
+            self.check_blocking(username)
+        except AttemptBlocked:
+            pass
+
     def on_form_valid(self, form):
         username = form.login_id.data
-        attempt = None
-        if self.should_limit_attempts():
-            if self.is_attempt_blocked(username):
-                # If we are rate-limiting this attempt, we don't want to proceed with validation.
-                # Validating may still allow brute forcing by measuring response time. Skipping it
-                # may help mitigate DoS attacks on the login page as password hashing is typically
-                # an expensive operation
-                attempt = self.log_attempt(username, success=False, is_during_lockout=True)
-                self.on_attempt_blocked()
-                return
-            else:
-                attempt = self.log_attempt(username, success=False)
+        try:
+            attempt = self.check_blocking(username)
+        except AttemptBlocked:
+            # If we are rate-limiting this attempt, we don't want to proceed with validation.
+            # Validating may still allow brute forcing by measuring response time. Skipping it
+            # may help mitigate DoS attacks on the login page as password hashing is typically
+            # an expensive operation
+            return
 
         try:
             # We want to know if the login attempt was successful so we'll try
@@ -598,7 +672,7 @@ class OAuthLoginViewResponder(ViewResponder):
 class OAuthAuthorizeViewResponder(LoginResponderMixin, ViewResponder):
     """ OAuth logins, using a provider via authlib"""
     url = '/oauth-authorize/<name>'
-    template_name = 'keg_auth/flash-messages-only.html'
+    template_name = 'keg-auth/flash-messages-only.html'
 
     def get(self, *args, **kwargs):
         name = kwargs.get('name')
@@ -635,8 +709,9 @@ class ForgotPasswordViewResponder(AttemptLimitMixin, UserResponderMixin, FormRes
     url = '/forgot-password'
     form_cls = forms.ForgotPassword
     page_title = _('Initiate Password Reset')
-    template_name = 'keg_auth/forgot-password.html'
+    template_name = 'keg-auth/forgot-password.html'
     flash_success = _('Please check your email for the link to change your password.'), 'success'
+    _csrf_custom_handling = True
 
     def __call__(self, *args, **kwargs):
         if not flask.current_app.auth_manager.mail_manager:
@@ -644,17 +719,28 @@ class ForgotPasswordViewResponder(AttemptLimitMixin, UserResponderMixin, FormRes
 
         return super(ForgotPasswordViewResponder, self).__call__(*args, **kwargs)
 
+    def on_csrf_error(self):
+        try:
+            # ensure we log this even though the form didn't validate
+            self.check_blocking(flask.request.form.get('email', ''))
+        except AttemptBlocked:
+            pass
+
+    def on_form_error(self, form):
+        super().on_form_error(form)
+        try:
+            # ensure we log this even though the form didn't validate
+            self.check_blocking(form.email.data)
+        except AttemptBlocked:
+            pass
+
     def on_form_valid(self, form):
-        attempt = None
-        if self.should_limit_attempts():
-            if self.is_attempt_blocked(form.email.data):
-                # If we are rate-limiting this attempt, we don't want to proceed with validation.
-                # Validating may still allow brute forcing by measuring response time.
-                attempt = self.log_attempt(form.email.data, success=False, is_during_lockout=True)
-                self.on_attempt_blocked()
-                return
-            else:
-                attempt = self.log_attempt(form.email.data, success=False)
+        try:
+            attempt = self.check_blocking(form.email.data)
+        except AttemptBlocked:
+            # If we are rate-limiting this attempt, we don't want to proceed with validation.
+            # Validating may still allow brute forcing by measuring response time.
+            return
 
         try:
             user = self.parent.verify_user(login_id=form.email.data, allow_unverified=True)
@@ -977,150 +1063,6 @@ class LdapAuthenticator(KegAuthenticator):
         return False
 
 
-class OidcLoginViewResponder(LoginResponderMixin, ViewResponder):
-    """ OIDC logins, using an oauth token"""
-
-    flash_success = None
-    page_title = 'Log In'
-    template_name = 'keg_auth/flash-messages-only.html'
-
-    def __init__(self, parent):
-        warnings.warn(OidcAuthenticator.usage_warning, DeprecationWarning, 2)
-        super().__init__(parent)
-
-    def get(self, *args, **kwargs):
-        oidc = flask.current_app.auth_manager.oidc
-        oidc_check = oidc.require_login(lambda: True)()
-        if oidc_check is not True:
-            return oidc_check
-
-        login_id = oidc.user_getfield("preferred_username")
-
-        try:
-            user = self.parent.verify_user(login_id=login_id)
-
-            # User is active and password is verified
-            return self.on_success(user)
-        except UserNotFound:
-            self.on_invalid_user(login_id)
-        except UserInactive as exc:
-            self.on_inactive_user(exc.user)
-
-    def head(self, *args, **kwargs):
-        return flask.abort(405, valid_methods=['GET'])
-
-    def post(self, *args, **kwargs):
-        return flask.abort(405, valid_methods=['GET'])
-
-
-class OidcLogoutViewResponder(LogoutViewResponder):
-    """ OIDC logout requires some extra leg-work, because token gets refreshed server-side"""
-
-    def __init__(self, parent):
-        warnings.warn(OidcAuthenticator.usage_warning, DeprecationWarning, 2)
-        super().__init__(parent)
-
-    def get(self):
-        oidc = flask.current_app.auth_manager.oidc
-        url_login = flask.url_for(flask.current_app.auth_manager.endpoint('login'))
-        url_after_login = flask.url_for(flask.current_app.auth_manager.endpoint('after-login'))
-        bad_token_redirect_resp = flask.current_app.login_manager.unauthorized()
-
-        url_only_redirect = flask.current_app.config.get('KEGAUTH_OIDC_LOGOUT_REDIRECT')
-        if url_only_redirect:
-            flask_login.logout_user()
-            return flask.abort(flask.redirect(url_only_redirect))
-
-        """ Logout won't work if user isn't authenticated to begin with, i.e. there won't be a
-            token to use. Just redirect to a sane place to force a login to continue."""
-        try:
-            user_sub = oidc.user_getfield('sub')
-        except Exception as exc:
-            if 'User was not authenticated' not in str(exc):
-                raise
-            return flask.abort(flask.redirect(url_login))
-
-        """ In some cases e.g. app restart, credentials store may not have valid information in the
-            flask server-side info. In that case, clear the client token and refresh info from
-            the oauth source. We have to have a valid id token to make logout work."""
-        try:
-            from oauth2client.client import OAuth2Credentials
-            id_token = OAuth2Credentials.from_json(
-                oidc.credentials_store[user_sub]
-            ).token_response['id_token']
-        except KeyError:
-            oidc.logout()
-            return flask.abort(bad_token_redirect_resp)
-
-        """ Build the oauth request URI, which has to include the ID token. But, logout all client
-            session info before redirecting there."""
-        logout_request = '{}{}?id_token_hint={}&post_logout_redirect_uri={}'.format(
-            flask.current_app.config.get('OIDC_PROVIDER_URL'),
-            flask.current_app.config.get('OIDC_LOGOUT'),
-            str(id_token),
-            flask.current_app.config.get('OIDC_REDIRECT_BASE') + url_after_login,
-        )
-        oidc.logout()
-        flask_login.logout_user()
-        return flask.redirect(logout_request)
-
-
-class OidcAuthenticator(LoginAuthenticator):
-    """ Uses OIDC authentication with an oauth provider, validates against keg-auth db.
-
-    Warning: Deprecated.
-    """
-    responder_cls = {
-        'login': OidcLoginViewResponder,
-        'logout': OidcLogoutViewResponder,
-    }
-    usage_warning = (
-        'All OIDC objects are now deprecated and will be removed in a future version. Use the '
-        'OAuth authenticator alongside either a password authenticator or a redirect. '
-        'flask-oidc formed the core of this authenticator but has not received much maintenance '
-        'in the last few years. At this time, the library is depending on deprecated/removed '
-        'items in other libraries (such as itsdangerous) and will need to be updated to be '
-        'reliably operational again.'
-    )
-
-    def __init__(self, app):
-        warnings.warn(self.usage_warning, DeprecationWarning, 2)
-
-        from flask_oidc import OpenIDConnect
-
-        oidc_settings = {
-            'web': {
-                'client_id': app.config.get('OIDC_CLIENT_ID'),
-                'client_secret': app.config.get('OIDC_CLIENT_SECRET'),
-                'auth_uri': app.config.get('OIDC_PROVIDER_URL') + app.config.get('OIDC_AUTH_URI'),
-                'token_uri': app.config.get('OIDC_PROVIDER_URL') + app.config.get('OIDC_TOKEN_URI'),
-                'issuer': app.config.get('OIDC_PROVIDER_URL') + app.config.get('OIDC_ISSUER'),
-                'userinfo_uri': app.config.get('OIDC_PROVIDER_URL')
-                + app.config.get('OIDC_USERINFO_URI'),
-                'redirect_uris': [
-                    app.config.get('OIDC_REDIRECT_BASE') + app.config.get('OIDC_CALLBACK_ROUTE')
-                ]
-            }
-        }
-
-        class KAOpenIDConnect(OpenIDConnect):
-            def load_secrets(self, app):
-                return oidc_settings
-        app.auth_manager.oidc = KAOpenIDConnect(app)
-
-        super().__init__(app)
-
-    def verify_user(self, login_id=None):
-        user = self.user_ent.query.filter_by(username=login_id).one_or_none()
-
-        if not user:
-            raise UserNotFound
-        if not user.is_active:
-            raise UserInactive(user)
-
-        return user
-
-
 class JwtRequestLoader(TokenLoaderMixin, RequestLoader):
     """ Loader for JWT tokens contained in the Authorization header.
 
