@@ -12,7 +12,7 @@ class TestUpdateLastLogin(object):
 
     @freezegun.freeze_time("2018-10-01 15:00:00")
     def test_it_will_update_last_login(self):
-        u = ents.User.testing_create(email=u"test@bar.com", last_login_utc=None)
+        u = ents.User.fake(email=u"test@bar.com", last_login_utc=None)
         update_last_login(flask.current_app, u)
         ents.db.session.remove()
         u = ents.User.get_by(email=u"test@bar.com")
